@@ -33,7 +33,7 @@ def simplify_graphml(graphpath, directed=True, simplify=True):
         g.vs[x] = [float(xx) for xx in g.vs[x]]
         g.vs[y] = [float(yy) for yy in g.vs[y]]
 
-        g = add_lengths(g, xattrib, yattrib)
+        g = add_lengths(g, x, y)
 
     return g
 
